netapp_ontap.models.storage_bridge_fc_ports API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_bridge_fc_ports`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageBridgeFcPortsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageBridgeFcPorts object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `configured_data_rate: float GET POST PATCH`

    Bridge FC port configured data rate, in Gbps

  `connection_mode: str GET POST PATCH`

    Bridge FC port configured connection mode

    Valid choices:

    - loop
    - ptp
    - loop_preferred
    - ptp_preferred
  `data_rate_capability: float GET POST PATCH`

    Bridge FC port data rate capability, in Gbps

  `enabled: bool GET POST PATCH`

    Indicates whether the bridge FC port is enabled.

  `id: Size GET POST PATCH`

    Bridge FC port index

  `negotiated_data_rate: float GET POST PATCH`

    Bridge FC port negotiated data rate, in Gbps

  `peer_wwn: str GET POST PATCH`

    Bridge FC port peer port world wide name

    Example: 200650eb1a238892

  `sfp: StorageBridgeFcPortsSfp GET POST PATCH`

    The sfp field of the storage_bridge_fc_ports.

  `state: str GET POST PATCH`

    Bridge FC port state

    Valid choices:

    - error
    - online
    - offline
  `wwn: str GET POST PATCH`

    Bridge FC port world wide name

    Example: 2100001086a54100